@@ -1,3 +1,4 @@
 from uuid_generator import UUIDGenerator
 from pluralize_engine import PluralizeEngine
-from core import ActiveRedis, ActiveRedisModel
+from active_redis import ActiveRedis
+from active_redis_model import ActiveRedisModel
